@@ -6,9 +6,9 @@ The main class here is ``_ParamsInitMixin``, which simply adds the __init__ meth
 
 __author__ = "Matteo Ferla. [Github](https://github.com/matteoferla)"
 __email__ = "matteo.ferla@gmail.com"
-__date__ = "10 July 2020 A.D."
+__date__ = "5 November 2020 A.D."
 __license__ = "MIT"
-__version__ = "1.1.0"
+__version__ = "1.1.3"
 __citation__ = "None."
 
 ########################################################################################################################
