@@ -7,9 +7,9 @@ __doc__ = \
 
 __author__ = "Matteo Ferla. [Github](https://github.com/matteoferla)"
 __email__ = "matteo.ferla@gmail.com"
-__date__ = "10 July 2020 A.D."
+__date__ = "5 November 2020 A.D."
 __license__ = "MIT"
-__version__ = "1.1.0"
+__version__ = "1.1.3"
 __citation__ = "None."
 
 ########################################################################################################################
@@ -81,7 +81,8 @@ class _RDKitInitMixin(_RDKitCovertMixin):
         :rtype: instance
         """
         cls.log.debug('`from_smiles_w_pdbblock` called...')
-        pdb = Chem.MolFromPDBBlock(pdb_block, removeHs=False, proximityBonding=proximityBonding)
+        pdb = Chem.MolFromPDBBlock(pdb_block, removeHs=True, proximityBonding=proximityBonding)
+        # removeHs=True is no longer an option because it causes issues with the template step.
         return cls._from_smiles_w_pdb(pdb, smiles, generic, name)
 
 
@@ -101,7 +102,8 @@ class _RDKitInitMixin(_RDKitCovertMixin):
         :rtype: instance
         """
         cls.log.debug('`from_smiles_w_pdbfile` called...')
-        pdb = Chem.MolFromPDBFile(pdb_file, removeHs=False, proximityBonding=proximityBonding)
+        pdb = Chem.MolFromPDBFile(pdb_file, removeHs=True, proximityBonding=proximityBonding)
+        # removeHs=True is no longer an option because it causes issues with the template step.
         return cls._from_smiles_w_pdb(pdb, smiles, generic, name)
 
     @classmethod
@@ -115,6 +117,7 @@ class _RDKitInitMixin(_RDKitCovertMixin):
             if atom.GetSymbol() == '*':
                 atom.SetAtomicNum(9)
                 dummies.append(atom.GetIdx())
+        Chem.SanitizeMol(good)
         good = AllChem.AddHs(good)
         AllChem.EmbedMolecule(good)
         AllChem.ComputeGasteigerCharges(good)
@@ -124,8 +127,9 @@ class _RDKitInitMixin(_RDKitCovertMixin):
         self = cls.load_mol(good, generic=generic, name=name)
         self.move_aside()
         self.rename_from_template(dodgy)
+        self.move_back()
         self.convert_mol()
         #####
         warnings.warn('CHI DISABLED. - has issues with this mode')  # todo correct this issue!
-        self.CHI = [] # !!!!
+        self.CHI.data = [] # !!!!
         return self
\ No newline at end of file
