@@ -14,9 +14,9 @@ It does not rely on any ``Params`` entry stuff. So can be used by itself for tes
 
 __author__ = "Matteo Ferla. [Github](https://github.com/matteoferla)"
 __email__ = "matteo.ferla@gmail.com"
-__date__ = "10 July 2020 A.D."
+__date__ = "5 November 2020 A.D."
 __license__ = "MIT"
-__version__ = "1.1.0"
+__version__ = "1.1.3"
 __citation__ = "None."
 
 ########################################################################################################################
@@ -526,6 +526,7 @@ class _RDKitPrepMixin(_RDKitRenameMixin):
                 atom.SetAtomicNum(6)
                 atom.SetHybridization(Chem.HybridizationType.SP3)
                 changed.append(atom.GetIdx())
+        Chem.SanitizeMol(self.mol)
         AllChem.ComputeGasteigerCharges(self.mol, throwOnParamFailure=False)
         for i, atom in enumerate(self.mol.GetAtoms()):
             if i in changed:
@@ -569,7 +570,39 @@ class _RDKitPrepMixin(_RDKitRenameMixin):
         :return:
         """
         for i in range(self.mol.GetNumAtoms()):
-            self._set_PDBInfo_atomname(self.mol.GetAtomWithIdx(i), f'XX{i: <2}', overwrite=True)
+            atom = self.mol.GetAtomWithIdx(i)
+            atomname = self._get_PDBInfo_atomname(atom, throw=False)
+            if atomname:
+                atom.SetProp('_OriginalName', atomname)
+            if atom.GetSymbol() != '*':
+                self._set_PDBInfo_atomname(atom, f'XX{i: <2}', overwrite=True)
+
+    def move_back(self):
+        """
+        Removes the ugly XX!
+
+        :return:
+        """
+        atomnames = []
+        for atom in self.mol.GetAtoms():
+            atomname = self._get_PDBInfo_atomname(atom, throw=False)
+            atomnames.append(atomname)
+        # find bad ones!
+        for atom in self.mol.GetAtoms():
+            atomname = self._get_PDBInfo_atomname(atom, throw=False)
+            if 'XX' in atomname:
+                original = atom.GetProp('_OriginalName')
+                if original not in atomnames:
+                    self._set_PDBInfo_atomname(atom, original, overwrite=True)
+                else:
+                    for i in range(1, 100):
+                        candidate = f'{atom.GetSymbol: >2}{i: <2}'
+                        if candidate not in atomnames:
+                            self._set_PDBInfo_atomname(atom, candidate, overwrite=True)
+                            break
+                    else:
+                        self.log.warning(f'Could not find a decent atomname for {atom.GetIdx()}')
+
 
     def add_Hs(self):
         """
@@ -579,6 +612,7 @@ class _RDKitPrepMixin(_RDKitRenameMixin):
         self.log.debug('Adding hydrogens')
         self.mol = AllChem.AddHs(self.mol)
         changed = []
+        Chem.SanitizeMol(self.mol)
         for atom in self.mol.GetAtoms():
             if atom.GetSymbol() == '*':
                 atom.SetAtomicNum(6)
